aboutsummaryrefslogtreecommitdiff
path: root/AppKit
diff options
context:
space:
mode:
authorGravatar gtm.daemon <gtm.daemon@7dc7ac4e-7543-0410-b95c-c1676fc8e2a3>2011-11-02 18:30:18 +0000
committerGravatar gtm.daemon <gtm.daemon@7dc7ac4e-7543-0410-b95c-c1676fc8e2a3>2011-11-02 18:30:18 +0000
commit1204639d4aeeac3d3dda7b0c53b8941266b9e685 (patch)
tree37db0dee0bdaad00e3c6faf9c50d2c3804b598b6 /AppKit
parentfe8209a1d04223c70727a4e87cfe53d5bd4192c0 (diff)
[Author: thomasvl]
- Support for localizing non datasource versions of NSComboxBox (http://code.google.com/p/google-toolbox-for-mac/issues/detail?id=77). - Fix up some category names. - Avoid conflicting category names. - Move placeholder string support down to NSTextField instead of NSSearchField. - Support for NSTextField placeholder in unittesting state. - Support for non datasource combobox values in unittesting state. - Fix NSSegmentControl localization support. - Add explicit tests for no localized values and document it in the strings file. - Unittesting for as much as possible of the above. R=dmaclach DELTA=762 (660 added, 55 deleted, 47 changed)
Diffstat (limited to 'AppKit')
-rw-r--r--AppKit/GTMUILocalizer.m53
-rw-r--r--AppKit/GTMUILocalizerTestWindow.xib258
-rw-r--r--AppKit/GTMUILocalizerTestWindow_10_4.xib246
-rw-r--r--AppKit/TestData/GTMUILocalizerWindow3State.10_4_SDK.gtmUTState40
-rw-r--r--AppKit/TestData/GTMUILocalizerWindow3State.gtmUTState42
-rw-r--r--AppKit/TestData/Resources/English.lproj/Localizable.strings8
6 files changed, 593 insertions, 54 deletions
diff --git a/AppKit/GTMUILocalizerTestWindow.xib b/AppKit/GTMUILocalizerTestWindow.xib
index 6161945..8bb4172 100644
--- a/AppKit/GTMUILocalizerTestWindow.xib
+++ b/AppKit/GTMUILocalizerTestWindow.xib
@@ -2,18 +2,18 @@
<archive type="com.apple.InterfaceBuilder3.Cocoa.XIB" version="7.10">
<data>
<int key="IBDocument.SystemTarget">1050</int>
- <string key="IBDocument.SystemVersion">10D2063a</string>
- <string key="IBDocument.InterfaceBuilderVersion">762</string>
- <string key="IBDocument.AppKitVersion">1038.29</string>
- <string key="IBDocument.HIToolboxVersion">460.00</string>
+ <string key="IBDocument.SystemVersion">10K549</string>
+ <string key="IBDocument.InterfaceBuilderVersion">851</string>
+ <string key="IBDocument.AppKitVersion">1038.36</string>
+ <string key="IBDocument.HIToolboxVersion">461.00</string>
<object class="NSMutableDictionary" key="IBDocument.PluginVersions">
<string key="NS.key.0">com.apple.InterfaceBuilder.CocoaPlugin</string>
- <string key="NS.object.0">762</string>
+ <string key="NS.object.0">851</string>
</object>
<object class="NSMutableArray" key="IBDocument.EditedObjectIDs">
<bool key="EncodedWithXMLCoder">YES</bool>
+ <integer value="23"/>
<integer value="52"/>
- <integer value="22"/>
<integer value="41"/>
</object>
<object class="NSArray" key="IBDocument.PluginDependencies">
@@ -196,7 +196,7 @@
<int key="NSColorSpace">6</int>
<string key="NSCatalogName">System</string>
<string key="NSColorName">controlColor</string>
- <object class="NSColor" key="NSColor">
+ <object class="NSColor" key="NSColor" id="125228242">
<int key="NSColorSpace">3</int>
<bytes key="NSWhite">MC42NjY2NjY2NjY3AA</bytes>
</object>
@@ -1204,6 +1204,107 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<int key="NSSegmentStyle">1</int>
</object>
</object>
+ <object class="NSComboBox" id="931776629">
+ <reference key="NSNextResponder" ref="405137086"/>
+ <int key="NSvFlags">268</int>
+ <string key="NSFrame">{{371, 180}, {92, 26}}</string>
+ <reference key="NSSuperview" ref="405137086"/>
+ <bool key="NSEnabled">YES</bool>
+ <object class="NSComboBoxCell" key="NSCell" id="763797856">
+ <int key="NSCellFlags">343014976</int>
+ <int key="NSCellFlags2">272630784</int>
+ <string key="NSContents">^Label1</string>
+ <reference key="NSSupport" ref="168773824"/>
+ <string key="NSPlaceholderString">^Placeholder1</string>
+ <reference key="NSControlView" ref="931776629"/>
+ <bool key="NSDrawsBackground">YES</bool>
+ <reference key="NSBackgroundColor" ref="854948635"/>
+ <reference key="NSTextColor" ref="50010148"/>
+ <int key="NSVisibleItemCount">4</int>
+ <bool key="NSHasVerticalScroller">YES</bool>
+ <object class="NSMutableArray" key="NSPopUpListData">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <string>^Choice1</string>
+ <string>^Choice2</string>
+ <string>^Choice3</string>
+ <string>^Choice4</string>
+ <string>^Choice5</string>
+ </object>
+ <reference key="NSDelegate" ref="931776629"/>
+ <object class="NSComboTableView" key="NSTableView" id="452420746">
+ <reference key="NSNextResponder"/>
+ <int key="NSvFlags">274</int>
+ <string key="NSFrameSize">{13, 105}</string>
+ <reference key="NSSuperview"/>
+ <reference key="NSWindow"/>
+ <bool key="NSEnabled">YES</bool>
+ <object class="NSMutableArray" key="NSTableColumns">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <object class="NSTableColumn">
+ <integer value="0" key="NSIdentifier"/>
+ <double key="NSWidth">10</double>
+ <double key="NSMinWidth">10</double>
+ <double key="NSMaxWidth">1000</double>
+ <object class="NSTableHeaderCell" key="NSHeaderCell">
+ <int key="NSCellFlags">75628032</int>
+ <int key="NSCellFlags2">0</int>
+ <string key="NSContents"/>
+ <object class="NSFont" key="NSSupport">
+ <string key="NSName">LucidaGrande</string>
+ <double key="NSSize">12</double>
+ <int key="NSfFlags">16</int>
+ </object>
+ <object class="NSColor" key="NSBackgroundColor">
+ <int key="NSColorSpace">3</int>
+ <bytes key="NSWhite">MC4zMzMzMzI5ODU2AA</bytes>
+ </object>
+ <reference key="NSTextColor" ref="695371698"/>
+ </object>
+ <object class="NSTextFieldCell" key="NSDataCell">
+ <int key="NSCellFlags">338820672</int>
+ <int key="NSCellFlags2">1024</int>
+ <reference key="NSSupport" ref="168773824"/>
+ <reference key="NSControlView" ref="452420746"/>
+ <bool key="NSDrawsBackground">YES</bool>
+ <object class="NSColor" key="NSBackgroundColor" id="156860821">
+ <int key="NSColorSpace">6</int>
+ <string key="NSCatalogName">System</string>
+ <string key="NSColorName">controlBackgroundColor</string>
+ <reference key="NSColor" ref="125228242"/>
+ </object>
+ <reference key="NSTextColor" ref="50010148"/>
+ </object>
+ <int key="NSResizingMask">3</int>
+ <bool key="NSIsResizeable">YES</bool>
+ <reference key="NSTableView" ref="452420746"/>
+ </object>
+ </object>
+ <double key="NSIntercellSpacingWidth">3</double>
+ <double key="NSIntercellSpacingHeight">2</double>
+ <reference key="NSBackgroundColor" ref="156860821"/>
+ <object class="NSColor" key="NSGridColor">
+ <int key="NSColorSpace">6</int>
+ <string key="NSCatalogName">System</string>
+ <string key="NSColorName">gridColor</string>
+ <object class="NSColor" key="NSColor">
+ <int key="NSColorSpace">3</int>
+ <bytes key="NSWhite">MC41AA</bytes>
+ </object>
+ </object>
+ <double key="NSRowHeight">19</double>
+ <string key="NSAction">tableViewAction:</string>
+ <int key="NSTvFlags">-765427712</int>
+ <reference key="NSDelegate" ref="763797856"/>
+ <reference key="NSDataSource" ref="763797856"/>
+ <reference key="NSTarget" ref="763797856"/>
+ <int key="NSColumnAutoresizingStyle">1</int>
+ <int key="NSDraggingSourceMaskForLocal">15</int>
+ <int key="NSDraggingSourceMaskForNonLocal">0</int>
+ <bool key="NSAllowsTypeSelect">YES</bool>
+ <int key="NSTableViewDraggingDestinationStyle">0</int>
+ </object>
+ </object>
+ </object>
</object>
<string key="NSFrameSize">{480, 270}</string>
<reference key="NSSuperview"/>
@@ -1631,6 +1732,7 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<reference ref="846591189"/>
<reference ref="161950549"/>
<reference ref="632547328"/>
+ <reference ref="931776629"/>
</object>
<reference key="parent" ref="158765462"/>
</object>
@@ -1873,6 +1975,20 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<reference key="object" ref="907223470"/>
<reference key="parent" ref="632547328"/>
</object>
+ <object class="IBObjectRecord">
+ <int key="objectID">173</int>
+ <reference key="object" ref="931776629"/>
+ <object class="NSMutableArray" key="children">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <reference ref="763797856"/>
+ </object>
+ <reference key="parent" ref="405137086"/>
+ </object>
+ <object class="IBObjectRecord">
+ <int key="objectID">174</int>
+ <reference key="object" ref="763797856"/>
+ <reference key="parent" ref="931776629"/>
+ </object>
</object>
</object>
<object class="NSMutableDictionary" key="flattenedProperties">
@@ -1900,6 +2016,9 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string>16.IBPluginDependency</string>
<string>169.IBPluginDependency</string>
<string>170.IBPluginDependency</string>
+ <string>173.IBPluginDependency</string>
+ <string>173.IBViewBoundsToFrameTransform</string>
+ <string>174.IBPluginDependency</string>
<string>2.IBPluginDependency</string>
<string>22.IBEditorWindowLastContentRect</string>
<string>22.IBPluginDependency</string>
@@ -1962,9 +2081,9 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
- <string>{{329, 451}, {480, 270}}</string>
+ <string>{{387, 451}, {480, 270}}</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
- <string>{{329, 451}, {480, 270}}</string>
+ <string>{{387, 451}, {480, 270}}</string>
<boolean value="NO"/>
<string>{196, 240}</string>
<string>{{357, 418}, {480, 270}}</string>
@@ -1981,9 +2100,14 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
- <string>{{960, 479}, {480, 270}}</string>
+ <object class="NSAffineTransform">
+ <bytes key="NSTransformStruct">P4AAAL+AAABDuYAAw0wAAA</bytes>
+ </object>
+ <string>com.apple.InterfaceBuilder.CocoaPlugin</string>
+ <string>com.apple.InterfaceBuilder.CocoaPlugin</string>
+ <string>{{948, 629}, {480, 270}}</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
- <string>{{960, 479}, {480, 270}}</string>
+ <string>{{948, 629}, {480, 270}}</string>
<boolean value="NO"/>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>{{126, 673}, {161, 23}}</string>
@@ -2054,7 +2178,7 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
</object>
</object>
<nil key="sourceID"/>
- <int key="maxID">170</int>
+ <int key="maxID">174</int>
</object>
<object class="IBClassDescriber" key="IBDocument.Classes">
<object class="NSMutableArray" key="referencedPartialClassDescriptions">
@@ -2077,6 +2201,30 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string>id</string>
</object>
</object>
+ <object class="NSMutableDictionary" key="toOneOutletInfosByName">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <object class="NSArray" key="dict.sortedKeys">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <string>otherObjectToLocalize_</string>
+ <string>owner_</string>
+ <string>yetAnotherObjectToLocalize_</string>
+ </object>
+ <object class="NSMutableArray" key="dict.values">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <object class="IBToOneOutletInfo">
+ <string key="name">otherObjectToLocalize_</string>
+ <string key="candidateClassName">id</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">owner_</string>
+ <string key="candidateClassName">id</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">yetAnotherObjectToLocalize_</string>
+ <string key="candidateClassName">id</string>
+ </object>
+ </object>
+ </object>
<object class="IBClassDescriptionSource" key="sourceIdentifier">
<string key="majorKey">IBProjectSource</string>
<string key="minorKey">AppKit/GTMUILocalizer.h</string>
@@ -2104,6 +2252,40 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string>NSWindow</string>
</object>
</object>
+ <object class="NSMutableDictionary" key="toOneOutletInfosByName">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <object class="NSArray" key="dict.sortedKeys">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <string>anotherWindow_</string>
+ <string>bindingsSearchField_</string>
+ <string>bindingsTextField_</string>
+ <string>otherMenu_</string>
+ <string>otherWindow_</string>
+ </object>
+ <object class="NSMutableArray" key="dict.values">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <object class="IBToOneOutletInfo">
+ <string key="name">anotherWindow_</string>
+ <string key="candidateClassName">NSWindow</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">bindingsSearchField_</string>
+ <string key="candidateClassName">NSSearchField</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">bindingsTextField_</string>
+ <string key="candidateClassName">NSTextField</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">otherMenu_</string>
+ <string key="candidateClassName">NSMenu</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">otherWindow_</string>
+ <string key="candidateClassName">NSWindow</string>
+ </object>
+ </object>
+ </object>
<object class="IBClassDescriptionSource" key="sourceIdentifier">
<string key="majorKey">IBProjectSource</string>
<string key="minorKey">AppKit/GTMUILocalizerTest.h</string>
@@ -2124,6 +2306,10 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
</object>
</object>
<object class="IBPartialClassDescription">
+ <string key="className">NSBox</string>
+ <reference key="sourceIdentifier" ref="485269976"/>
+ </object>
+ <object class="IBPartialClassDescription">
<string key="className">NSButton</string>
<reference key="sourceIdentifier" ref="485269976"/>
</object>
@@ -2132,6 +2318,10 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<reference key="sourceIdentifier" ref="485269976"/>
</object>
<object class="IBPartialClassDescription">
+ <string key="className">NSComboBox</string>
+ <reference key="sourceIdentifier" ref="485269976"/>
+ </object>
+ <object class="IBPartialClassDescription">
<string key="className">NSControl</string>
<reference key="sourceIdentifier" ref="485269976"/>
</object>
@@ -2165,13 +2355,6 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string key="className">NSObject</string>
<object class="IBClassDescriptionSource" key="sourceIdentifier">
<string key="majorKey">IBProjectSource</string>
- <string key="minorKey">Foundation/GTMHTTPServer.h</string>
- </object>
- </object>
- <object class="IBPartialClassDescription">
- <string key="className">NSObject</string>
- <object class="IBClassDescriptionSource" key="sourceIdentifier">
- <string key="majorKey">IBProjectSource</string>
<string key="minorKey">Foundation/GTMNSAppleEventDescriptor+Foundation.h</string>
</object>
</object>
@@ -2204,6 +2387,10 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
</object>
</object>
<object class="IBPartialClassDescription">
+ <string key="className">NSSegmentedControl</string>
+ <reference key="sourceIdentifier" ref="485269976"/>
+ </object>
+ <object class="IBPartialClassDescription">
<string key="className">NSTabView</string>
<reference key="sourceIdentifier" ref="485269976"/>
</object>
@@ -2216,6 +2403,14 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<reference key="sourceIdentifier" ref="485269976"/>
</object>
<object class="IBPartialClassDescription">
+ <string key="className">NSToolbar</string>
+ <reference key="sourceIdentifier" ref="485269976"/>
+ </object>
+ <object class="IBPartialClassDescription">
+ <string key="className">NSToolbarItem</string>
+ <reference key="sourceIdentifier" ref="485269976"/>
+ </object>
+ <object class="IBPartialClassDescription">
<string key="className">NSView</string>
<object class="IBClassDescriptionSource" key="sourceIdentifier" id="308904550">
<string key="majorKey">IBProjectSource</string>
@@ -2321,6 +2516,22 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
</object>
</object>
<object class="IBPartialClassDescription">
+ <string key="className">NSComboBox</string>
+ <string key="superclassName">NSTextField</string>
+ <object class="IBClassDescriptionSource" key="sourceIdentifier">
+ <string key="majorKey">IBFrameworkSource</string>
+ <string key="minorKey">AppKit.framework/Headers/NSComboBox.h</string>
+ </object>
+ </object>
+ <object class="IBPartialClassDescription">
+ <string key="className">NSComboBoxCell</string>
+ <string key="superclassName">NSTextFieldCell</string>
+ <object class="IBClassDescriptionSource" key="sourceIdentifier">
+ <string key="majorKey">IBFrameworkSource</string>
+ <string key="minorKey">AppKit.framework/Headers/NSComboBoxCell.h</string>
+ </object>
+ </object>
+ <object class="IBPartialClassDescription">
<string key="className">NSControl</string>
<string key="superclassName">NSView</string>
<object class="IBClassDescriptionSource" key="sourceIdentifier" id="498926182">
@@ -2847,6 +3058,13 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string key="NS.key.0">showWindow:</string>
<string key="NS.object.0">id</string>
</object>
+ <object class="NSMutableDictionary" key="actionInfosByName">
+ <string key="NS.key.0">showWindow:</string>
+ <object class="IBActionInfo" key="NS.object.0">
+ <string key="name">showWindow:</string>
+ <string key="candidateClassName">id</string>
+ </object>
+ </object>
<object class="IBClassDescriptionSource" key="sourceIdentifier">
<string key="majorKey">IBFrameworkSource</string>
<string key="minorKey">AppKit.framework/Headers/NSWindowController.h</string>
@@ -2862,7 +3080,7 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
</object>
<object class="NSMutableDictionary" key="IBDocument.PluginDeclaredDependencyDefaults">
<string key="NS.key.0">com.apple.InterfaceBuilder.CocoaPlugin.macosx</string>
- <integer value="1060" key="NS.object.0"/>
+ <integer value="1050" key="NS.object.0"/>
</object>
<object class="NSMutableDictionary" key="IBDocument.PluginDeclaredDevelopmentDependencies">
<string key="NS.key.0">com.apple.InterfaceBuilder.CocoaPlugin.InterfaceBuilder3</string>
diff --git a/AppKit/GTMUILocalizerTestWindow_10_4.xib b/AppKit/GTMUILocalizerTestWindow_10_4.xib
index 93cb909..6316e33 100644
--- a/AppKit/GTMUILocalizerTestWindow_10_4.xib
+++ b/AppKit/GTMUILocalizerTestWindow_10_4.xib
@@ -2,18 +2,18 @@
<archive type="com.apple.InterfaceBuilder3.Cocoa.XIB" version="7.10">
<data>
<int key="IBDocument.SystemTarget">1040</int>
- <string key="IBDocument.SystemVersion">10D2063a</string>
- <string key="IBDocument.InterfaceBuilderVersion">762</string>
- <string key="IBDocument.AppKitVersion">1038.29</string>
- <string key="IBDocument.HIToolboxVersion">460.00</string>
+ <string key="IBDocument.SystemVersion">10K549</string>
+ <string key="IBDocument.InterfaceBuilderVersion">851</string>
+ <string key="IBDocument.AppKitVersion">1038.36</string>
+ <string key="IBDocument.HIToolboxVersion">461.00</string>
<object class="NSMutableDictionary" key="IBDocument.PluginVersions">
<string key="NS.key.0">com.apple.InterfaceBuilder.CocoaPlugin</string>
- <string key="NS.object.0">762</string>
+ <string key="NS.object.0">851</string>
</object>
<object class="NSMutableArray" key="IBDocument.EditedObjectIDs">
<bool key="EncodedWithXMLCoder">YES</bool>
<integer value="35"/>
- <integer value="54"/>
+ <integer value="120"/>
<integer value="22"/>
</object>
<object class="NSArray" key="IBDocument.PluginDependencies">
@@ -117,7 +117,7 @@
<int key="NSColorSpace">6</int>
<string key="NSCatalogName">System</string>
<string key="NSColorName">controlColor</string>
- <object class="NSColor" key="NSColor">
+ <object class="NSColor" key="NSColor" id="792644860">
<int key="NSColorSpace">3</int>
<bytes key="NSWhite">MC42NjY2NjY2NjY3AA</bytes>
</object>
@@ -1089,6 +1089,107 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string key="NSFrame">{{42, 66}, {106, 45}}</string>
<reference key="NSSuperview" ref="405137086"/>
</object>
+ <object class="NSComboBox" id="311378109">
+ <reference key="NSNextResponder" ref="405137086"/>
+ <int key="NSvFlags">268</int>
+ <string key="NSFrame">{{371, 180}, {92, 26}}</string>
+ <reference key="NSSuperview" ref="405137086"/>
+ <bool key="NSEnabled">YES</bool>
+ <object class="NSComboBoxCell" key="NSCell" id="693732256">
+ <int key="NSCellFlags">343014976</int>
+ <int key="NSCellFlags2">272630784</int>
+ <string key="NSContents">^Label1</string>
+ <reference key="NSSupport" ref="168773824"/>
+ <string key="NSPlaceholderString">^Placeholder1</string>
+ <reference key="NSControlView" ref="311378109"/>
+ <bool key="NSDrawsBackground">YES</bool>
+ <reference key="NSBackgroundColor" ref="407928047"/>
+ <reference key="NSTextColor" ref="50010148"/>
+ <int key="NSVisibleItemCount">4</int>
+ <bool key="NSHasVerticalScroller">YES</bool>
+ <object class="NSMutableArray" key="NSPopUpListData">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <string>^Choice1</string>
+ <string>^Choice2</string>
+ <string>^Choice3</string>
+ <string>^Choice4</string>
+ <string>^Choice5</string>
+ </object>
+ <reference key="NSDelegate" ref="311378109"/>
+ <object class="NSComboTableView" key="NSTableView" id="743163681">
+ <reference key="NSNextResponder"/>
+ <int key="NSvFlags">274</int>
+ <string key="NSFrameSize">{13, 105}</string>
+ <reference key="NSSuperview"/>
+ <reference key="NSWindow"/>
+ <bool key="NSEnabled">YES</bool>
+ <object class="NSMutableArray" key="NSTableColumns">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <object class="NSTableColumn">
+ <integer value="0" key="NSIdentifier"/>
+ <double key="NSWidth">10</double>
+ <double key="NSMinWidth">10</double>
+ <double key="NSMaxWidth">1000</double>
+ <object class="NSTableHeaderCell" key="NSHeaderCell">
+ <int key="NSCellFlags">75628032</int>
+ <int key="NSCellFlags2">0</int>
+ <string key="NSContents"/>
+ <object class="NSFont" key="NSSupport">
+ <string key="NSName">LucidaGrande</string>
+ <double key="NSSize">12</double>
+ <int key="NSfFlags">16</int>
+ </object>
+ <object class="NSColor" key="NSBackgroundColor">
+ <int key="NSColorSpace">3</int>
+ <bytes key="NSWhite">MC4zMzMzMzI5ODU2AA</bytes>
+ </object>
+ <reference key="NSTextColor" ref="695371698"/>
+ </object>
+ <object class="NSTextFieldCell" key="NSDataCell">
+ <int key="NSCellFlags">338820672</int>
+ <int key="NSCellFlags2">1024</int>
+ <reference key="NSSupport" ref="168773824"/>
+ <reference key="NSControlView" ref="743163681"/>
+ <bool key="NSDrawsBackground">YES</bool>
+ <object class="NSColor" key="NSBackgroundColor" id="619521113">
+ <int key="NSColorSpace">6</int>
+ <string key="NSCatalogName">System</string>
+ <string key="NSColorName">controlBackgroundColor</string>
+ <reference key="NSColor" ref="792644860"/>
+ </object>
+ <reference key="NSTextColor" ref="50010148"/>
+ </object>
+ <int key="NSResizingMask">3</int>
+ <bool key="NSIsResizeable">YES</bool>
+ <reference key="NSTableView" ref="743163681"/>
+ </object>
+ </object>
+ <double key="NSIntercellSpacingWidth">3</double>
+ <double key="NSIntercellSpacingHeight">2</double>
+ <reference key="NSBackgroundColor" ref="619521113"/>
+ <object class="NSColor" key="NSGridColor">
+ <int key="NSColorSpace">6</int>
+ <string key="NSCatalogName">System</string>
+ <string key="NSColorName">gridColor</string>
+ <object class="NSColor" key="NSColor">
+ <int key="NSColorSpace">3</int>
+ <bytes key="NSWhite">MC41AA</bytes>
+ </object>
+ </object>
+ <double key="NSRowHeight">19</double>
+ <string key="NSAction">tableViewAction:</string>
+ <int key="NSTvFlags">-765427712</int>
+ <reference key="NSDelegate" ref="693732256"/>
+ <reference key="NSDataSource" ref="693732256"/>
+ <reference key="NSTarget" ref="693732256"/>
+ <int key="NSColumnAutoresizingStyle">1</int>
+ <int key="NSDraggingSourceMaskForLocal">15</int>
+ <int key="NSDraggingSourceMaskForNonLocal">0</int>
+ <bool key="NSAllowsTypeSelect">YES</bool>
+ <int key="NSTableViewDraggingDestinationStyle">0</int>
+ </object>
+ </object>
+ </object>
</object>
<string key="NSFrameSize">{480, 270}</string>
<reference key="NSSuperview"/>
@@ -1549,6 +1650,7 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<reference ref="735149545"/>
<reference ref="846591189"/>
<reference ref="161950549"/>
+ <reference ref="311378109"/>
</object>
<reference key="parent" ref="158765462"/>
</object>
@@ -1757,6 +1859,20 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<reference key="object" ref="129694561"/>
<reference key="parent" ref="0"/>
</object>
+ <object class="IBObjectRecord">
+ <int key="objectID">120</int>
+ <reference key="object" ref="311378109"/>
+ <object class="NSMutableArray" key="children">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <reference ref="693732256"/>
+ </object>
+ <reference key="parent" ref="405137086"/>
+ </object>
+ <object class="IBObjectRecord">
+ <int key="objectID">121</int>
+ <reference key="object" ref="693732256"/>
+ <reference key="parent" ref="311378109"/>
+ </object>
</object>
</object>
<object class="NSMutableDictionary" key="flattenedProperties">
@@ -1777,6 +1893,9 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string>101.IBPluginDependency</string>
<string>11.IBPluginDependency</string>
<string>12.IBPluginDependency</string>
+ <string>120.IBPluginDependency</string>
+ <string>120.IBViewBoundsToFrameTransform</string>
+ <string>121.IBPluginDependency</string>
<string>13.IBPluginDependency</string>
<string>14.IBPluginDependency</string>
<string>15.IBPluginDependency</string>
@@ -1840,9 +1959,9 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
- <string>{{174, 487}, {480, 270}}</string>
+ <string>{{174, 328}, {480, 270}}</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
- <string>{{174, 487}, {480, 270}}</string>
+ <string>{{174, 328}, {480, 270}}</string>
<boolean value="NO"/>
<string>{196, 240}</string>
<string>{{357, 418}, {480, 270}}</string>
@@ -1852,13 +1971,18 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
+ <object class="NSAffineTransform">
+ <bytes key="NSTransformStruct">P4AAAL+AAABDuYAAw0wAAA</bytes>
+ </object>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
- <string>{{324, 479}, {480, 270}}</string>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
- <string>{{324, 479}, {480, 270}}</string>
+ <string>com.apple.InterfaceBuilder.CocoaPlugin</string>
+ <string>{{387, 479}, {480, 270}}</string>
+ <string>com.apple.InterfaceBuilder.CocoaPlugin</string>
+ <string>{{387, 479}, {480, 270}}</string>
<boolean value="NO"/>
<string>com.apple.InterfaceBuilder.CocoaPlugin</string>
<string>{{126, 673}, {161, 23}}</string>
@@ -1926,7 +2050,7 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
</object>
</object>
<nil key="sourceID"/>
- <int key="maxID">119</int>
+ <int key="maxID">121</int>
</object>
<object class="IBClassDescriber" key="IBDocument.Classes">
<object class="NSMutableArray" key="referencedPartialClassDescriptions">
@@ -1949,6 +2073,30 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string>id</string>
</object>
</object>
+ <object class="NSMutableDictionary" key="toOneOutletInfosByName">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <object class="NSArray" key="dict.sortedKeys">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <string>otherObjectToLocalize_</string>
+ <string>owner_</string>
+ <string>yetAnotherObjectToLocalize_</string>
+ </object>
+ <object class="NSMutableArray" key="dict.values">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <object class="IBToOneOutletInfo">
+ <string key="name">otherObjectToLocalize_</string>
+ <string key="candidateClassName">id</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">owner_</string>
+ <string key="candidateClassName">id</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">yetAnotherObjectToLocalize_</string>
+ <string key="candidateClassName">id</string>
+ </object>
+ </object>
+ </object>
<object class="IBClassDescriptionSource" key="sourceIdentifier">
<string key="majorKey">IBProjectSource</string>
<string key="minorKey">AppKit/GTMUILocalizer.h</string>
@@ -1976,6 +2124,40 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string>NSWindow</string>
</object>
</object>
+ <object class="NSMutableDictionary" key="toOneOutletInfosByName">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <object class="NSArray" key="dict.sortedKeys">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <string>anotherWindow_</string>
+ <string>bindingsSearchField_</string>
+ <string>bindingsTextField_</string>
+ <string>otherMenu_</string>
+ <string>otherWindow_</string>
+ </object>
+ <object class="NSMutableArray" key="dict.values">
+ <bool key="EncodedWithXMLCoder">YES</bool>
+ <object class="IBToOneOutletInfo">
+ <string key="name">anotherWindow_</string>
+ <string key="candidateClassName">NSWindow</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">bindingsSearchField_</string>
+ <string key="candidateClassName">NSSearchField</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">bindingsTextField_</string>
+ <string key="candidateClassName">NSTextField</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">otherMenu_</string>
+ <string key="candidateClassName">NSMenu</string>
+ </object>
+ <object class="IBToOneOutletInfo">
+ <string key="name">otherWindow_</string>
+ <string key="candidateClassName">NSWindow</string>
+ </object>
+ </object>
+ </object>
<object class="IBClassDescriptionSource" key="sourceIdentifier">
<string key="majorKey">IBProjectSource</string>
<string key="minorKey">AppKit/GTMUILocalizerTest.h</string>
@@ -1996,6 +2178,10 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
</object>
</object>
<object class="IBPartialClassDescription">
+ <string key="className">NSBox</string>
+ <reference key="sourceIdentifier" ref="485269976"/>
+ </object>
+ <object class="IBPartialClassDescription">
<string key="className">NSButton</string>
<reference key="sourceIdentifier" ref="485269976"/>
</object>
@@ -2004,6 +2190,10 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<reference key="sourceIdentifier" ref="485269976"/>
</object>
<object class="IBPartialClassDescription">
+ <string key="className">NSComboBox</string>
+ <reference key="sourceIdentifier" ref="485269976"/>
+ </object>
+ <object class="IBPartialClassDescription">
<string key="className">NSControl</string>
<reference key="sourceIdentifier" ref="485269976"/>
</object>
@@ -2037,13 +2227,6 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string key="className">NSObject</string>
<object class="IBClassDescriptionSource" key="sourceIdentifier">
<string key="majorKey">IBProjectSource</string>
- <string key="minorKey">Foundation/GTMHTTPServer.h</string>
- </object>
- </object>
- <object class="IBPartialClassDescription">
- <string key="className">NSObject</string>
- <object class="IBClassDescriptionSource" key="sourceIdentifier">
- <string key="majorKey">IBProjectSource</string>
<string key="minorKey">Foundation/GTMNSAppleEventDescriptor+Foundation.h</string>
</object>
</object>
@@ -2193,6 +2376,22 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
</object>
</object>
<object class="IBPartialClassDescription">
+ <string key="className">NSComboBox</string>
+ <string key="superclassName">NSTextField</string>
+ <object class="IBClassDescriptionSource" key="sourceIdentifier">
+ <string key="majorKey">IBFrameworkSource</string>
+ <string key="minorKey">AppKit.framework/Headers/NSComboBox.h</string>
+ </object>
+ </object>
+ <object class="IBPartialClassDescription">
+ <string key="className">NSComboBoxCell</string>
+ <string key="superclassName">NSTextFieldCell</string>
+ <object class="IBClassDescriptionSource" key="sourceIdentifier">
+ <string key="majorKey">IBFrameworkSource</string>
+ <string key="minorKey">AppKit.framework/Headers/NSComboBoxCell.h</string>
+ </object>
+ </object>
+ <object class="IBPartialClassDescription">
<string key="className">NSControl</string>
<string key="superclassName">NSView</string>
<object class="IBClassDescriptionSource" key="sourceIdentifier" id="187673849">
@@ -2690,6 +2889,13 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
<string key="NS.key.0">showWindow:</string>
<string key="NS.object.0">id</string>
</object>
+ <object class="NSMutableDictionary" key="actionInfosByName">
+ <string key="NS.key.0">showWindow:</string>
+ <object class="IBActionInfo" key="NS.object.0">
+ <string key="name">showWindow:</string>
+ <string key="candidateClassName">id</string>
+ </object>
+ </object>
<object class="IBClassDescriptionSource" key="sourceIdentifier">
<string key="majorKey">IBFrameworkSource</string>
<string key="minorKey">AppKit.framework/Headers/NSWindowController.h</string>
@@ -2705,7 +2911,7 @@ AAMAAAABAAEAAAFTAAMAAAAEAAAFwgAAAAAACAAIAAgACAABAAEAAQABA</bytes>
</object>
<object class="NSMutableDictionary" key="IBDocument.PluginDeclaredDependencyDefaults">
<string key="NS.key.0">com.apple.InterfaceBuilder.CocoaPlugin.macosx</string>
- <integer value="1060" key="NS.object.0"/>
+ <integer value="1050" key="NS.object.0"/>
</object>
<object class="NSMutableDictionary" key="IBDocument.PluginDeclaredDevelopmentDependencies">
<string key="NS.key.0">com.apple.InterfaceBuilder.CocoaPlugin.InterfaceBuilder3</string>
diff --git a/AppKit/TestData/GTMUILocalizerWindow3State.10_4_SDK.gtmUTState b/AppKit/TestData/GTMUILocalizerWindow3State.10_4_SDK.gtmUTState
index ed88b68..ea1d10c 100644
--- a/AppKit/TestData/GTMUILocalizerWindow3State.10_4_SDK.gtmUTState
+++ b/AppKit/TestData/GTMUILocalizerWindow3State.10_4_SDK.gtmUTState
@@ -293,6 +293,46 @@
<false/>
</dict>
</dict>
+ <key>ViewSubView 3</key>
+ <dict>
+ <key>ComboBoxNumberOfItems</key>
+ <integer>5</integer>
+ <key>ComboBoxNumberOfVisibleItems</key>
+ <integer>4</integer>
+ <key>ComboBoxObjectValue 0</key>
+ <string>Localized Choice 1</string>
+ <key>ComboBoxObjectValue 1</key>
+ <string>Localized Choice 2</string>
+ <key>ComboBoxObjectValue 2</key>
+ <string>Localized Choice 3</string>
+ <key>ComboBoxObjectValue 3</key>
+ <string>^Choice4</string>
+ <key>ComboBoxObjectValue 4</key>
+ <string>^Choice5</string>
+ <key>ControlIsEnabled</key>
+ <true/>
+ <key>ControlSelectedCell</key>
+ <dict>
+ <key>CellState</key>
+ <integer>0</integer>
+ <key>CellTag</key>
+ <integer>0</integer>
+ <key>CellTitle</key>
+ <string>Localized Label</string>
+ <key>CellValue</key>
+ <string>Localized Label</string>
+ </dict>
+ <key>ControlTag</key>
+ <integer>0</integer>
+ <key>ControlType</key>
+ <string>NSComboBox</string>
+ <key>ControlValue</key>
+ <string>Localized Label</string>
+ <key>PlaceHolderString</key>
+ <string>Localized Placeholder</string>
+ <key>ViewIsHidden</key>
+ <false/>
+ </dict>
</dict>
<key>WindowIsMain</key>
<false/>
diff --git a/AppKit/TestData/GTMUILocalizerWindow3State.gtmUTState b/AppKit/TestData/GTMUILocalizerWindow3State.gtmUTState
index 8352b5e..6958e6e 100644
--- a/AppKit/TestData/GTMUILocalizerWindow3State.gtmUTState
+++ b/AppKit/TestData/GTMUILocalizerWindow3State.gtmUTState
@@ -319,12 +319,52 @@
<key>Segment 1</key>
<string>Localized Segment 2</string>
<key>Segment 2</key>
- <string>Localized Segment 3</string>
+ <string>^Seg3</string>
<key>SegmentCount</key>
<integer>3</integer>
<key>ViewIsHidden</key>
<false/>
</dict>
+ <key>ViewSubView 4</key>
+ <dict>
+ <key>ComboBoxNumberOfItems</key>
+ <integer>5</integer>
+ <key>ComboBoxNumberOfVisibleItems</key>
+ <integer>4</integer>
+ <key>ComboBoxObjectValue 0</key>
+ <string>Localized Choice 1</string>
+ <key>ComboBoxObjectValue 1</key>
+ <string>Localized Choice 2</string>
+ <key>ComboBoxObjectValue 2</key>
+ <string>Localized Choice 3</string>
+ <key>ComboBoxObjectValue 3</key>
+ <string>^Choice4</string>
+ <key>ComboBoxObjectValue 4</key>
+ <string>^Choice5</string>
+ <key>ControlIsEnabled</key>
+ <true/>
+ <key>ControlSelectedCell</key>
+ <dict>
+ <key>CellState</key>
+ <integer>0</integer>
+ <key>CellTag</key>
+ <integer>0</integer>
+ <key>CellTitle</key>
+ <string>Localized Label</string>
+ <key>CellValue</key>
+ <string>Localized Label</string>
+ </dict>
+ <key>ControlTag</key>
+ <integer>0</integer>
+ <key>ControlType</key>
+ <string>NSComboBox</string>
+ <key>ControlValue</key>
+ <string>Localized Label</string>
+ <key>PlaceHolderString</key>
+ <string>Localized Placeholder</string>
+ <key>ViewIsHidden</key>
+ <false/>
+ </dict>
</dict>
<key>WindowIsMain</key>
<false/>
diff --git a/AppKit/TestData/Resources/English.lproj/Localizable.strings b/AppKit/TestData/Resources/English.lproj/Localizable.strings
index e6452a8..b45dc87 100644
--- a/AppKit/TestData/Resources/English.lproj/Localizable.strings
+++ b/AppKit/TestData/Resources/English.lproj/Localizable.strings
@@ -16,6 +16,9 @@
// the License.
//
+// NOTE: Some things in the UI aren't here to confirm that they get left
+// along instead of replaced with an empty string.
+
// GTMUILocalizerTest strings
"Button1" = "Localized Button";
"Label1" = "Localized Label";
@@ -39,7 +42,10 @@
"Box" = "Localized Box";
"Seg1" = "Localized Segment 1";
"Seg2" = "Localized Segment 2";
-"Seg3" = "Localized Segment 3";
+"Choice1" = "Localized Choice 1";
+"Choice2" = "Localized Choice 2";
+"Choice3" = "Localized Choice 3";
+"Placeholder1" = "Localized Placeholder";
// Binding localization strings.
"MultipleValuesPlaceholder" = "MultipleValuesPlaceholder";
diff --git a/AppKit/GTMUILocalizer.m b/AppKit/GTMUILocalizer.m
index 56b0b7d..ffcc11d 100644
--- a/AppKit/GTMUILocalizer.m
+++ b/AppKit/GTMUILocalizer.m
@@ -23,7 +23,7 @@
- (void)localizeAccessibility:(id)object;
- (void)localizeBindings:(id)object;
-// Never recursively call any of these methods. Always call
+// Never recursively call any of these methods. Always call
// -[self localizeObject:recursively:] otherwise bindings will not be
// localized properly.
- (void)localizeWindow:(NSWindow *)window recursively:(BOOL)recursive;
@@ -240,12 +240,12 @@
}
}
- // Do NSSearchField placeholders
- if ([view isKindOfClass:[NSSearchField class]]) {
- NSString *placeholder = [[(NSSearchField *)view cell] placeholderString];
+ // Do NSTextField placeholders
+ if ([view isKindOfClass:[NSTextField class]]) {
+ NSString *placeholder = [[(NSTextField *)view cell] placeholderString];
NSString *localizedPlaceholer = [self localizedStringForString:placeholder];
if (localizedPlaceholer) {
- [[(NSSearchField *)view cell] setPlaceholderString:localizedPlaceholer];
+ [[(NSTextField *)view cell] setPlaceholderString:localizedPlaceholer];
}
}
@@ -282,8 +282,37 @@
NSSegmentedControl *segmentedControl = (NSSegmentedControl *)view;
for (NSInteger i = 0; i < [segmentedControl segmentCount]; ++i) {
NSString *label = [segmentedControl labelForSegment:i];
- [segmentedControl setLabel:[self localizedStringForString:label]
- forSegment:i];
+ NSString *localizedLabel = [self localizedStringForString:label];
+ if (localizedLabel) {
+ [segmentedControl setLabel:localizedLabel forSegment:i];
+ }
+ }
+ }
+
+ // Do NSComboBox items.
+ if ([view isKindOfClass:[NSComboBox class]]) {
+ NSComboBox *combobox = (NSComboBox*)view;
+ // Make sure it doesn't use a DataSource.
+ if (![combobox usesDataSource]) {
+ NSMutableArray *localizedValues = [NSMutableArray array];
+ BOOL replaceValues = NO;
+ NSString *value;
+ GTM_FOREACH_OBJECT(value, [combobox objectValues]) {
+ NSString *localizedValue = nil;
+ if ([value isKindOfClass:[NSString class]]) {
+ localizedValue = [self localizedStringForString:value];
+ }
+ if (localizedValue) {
+ replaceValues = YES;
+ [localizedValues addObject:localizedValue];
+ } else {
+ [localizedValues addObject:value];
+ }
+ }
+ if (replaceValues) {
+ [combobox removeAllItems];
+ [combobox addItemsWithObjectValues:localizedValues];
+ }
}
}
}
@@ -343,10 +372,10 @@
NSString *path = [bindingInfo objectForKey:NSObservedKeyPathKey];
NSDictionary *options = [bindingInfo objectForKey:NSOptionsKey];
if (observedObject && path && options) {
- NSMutableDictionary *newOptions
+ NSMutableDictionary *newOptions
= [NSMutableDictionary dictionaryWithDictionary:options];
BOOL valueChanged = NO;
- for (size_t i = 0;
+ for (size_t i = 0;
i < sizeof(optionsToLocalize) / sizeof(optionsToLocalize[0]);
++i) {
NSString *key = optionsToLocalize[i];
@@ -362,9 +391,9 @@
if (valueChanged) {
// Only unbind and rebind if there is a change.
[object unbind:exposedBinding];
- [object bind:exposedBinding
- toObject:observedObject
- withKeyPath:path
+ [object bind:exposedBinding
+ toObject:observedObject
+ withKeyPath:path
options:newOptions];
}
}